@@ -1,18 +1,17 @@
 import { createSlice, PayloadAction } from '@reduxjs/toolkit';
 
-import { dateTime } from '@grafana/data';
 import { toStateKey } from 'app/features/variables/utils';
 
 import {
-  FooterMode,
   Report,
+  ReportFormat,
   ReportsState,
   ReportState,
   ReportTimeRange,
   SchedulingFrequency,
   StepKey,
 } from '../../types';
-import { defaultScaleFactor } from '../constants';
+import { defaultZoom } from '../constants';
 
 export const getTimezone = () => {
   // Older browser does not the internationalization API
@@ -34,8 +33,8 @@ export const getTimezone = () => {
 };
 
 export const defaultTimeRange = {
-  from: dateTime(null),
-  to: dateTime(null),
+  from: '',
+  to: '',
   raw: { from: '', to: '' },
 };
 
@@ -52,12 +51,14 @@ const blankReport: Report = {
     frequency: SchedulingFrequency.Weekly,
     timeZone: getTimezone(),
   },
-  formats: ['pdf'],
-  scaleFactor: defaultScaleFactor,
+  formats: [ReportFormat.PDF],
+  scaleFactor: defaultZoom,
   options: {
     orientation: 'landscape',
     layout: 'grid',
     timeRange: defaultTimeRange.raw as ReportTimeRange,
+    pdfShowTemplateVariables: false,
+    pdfCombineOneFile: false,
   },
   enableDashboardUrl: true,
   state: ReportState.Scheduled,
@@ -73,15 +74,6 @@ export const initialState: ReportsState = {
   isLoading: true,
   isUpdated: false,
   visitedSteps: [],
-  settings: {
-    branding: {
-      reportLogoUrl: '',
-      emailLogoUrl: '',
-      emailFooterMode: FooterMode.SentBy,
-      emailFooterText: '',
-      emailFooterLink: '',
-    },
-  },
 };
 
 const reportsSlice = createSlice({
@@ -134,6 +126,14 @@ const reportsSlice = createSlice({
     addVisitedStep: (state: ReportsState, action: PayloadAction<StepKey[]>) => {
       return { ...state, visitedSteps: [...state.visitedSteps, ...action.payload] };
     },
+    downloadCSVBegin: (state: ReportsState) => ({
+      ...state,
+      isDownloadingCSV: true,
+    }),
+    downloadCSVEnd: (state: ReportsState) => ({
+      ...state,
+      isDownloadingCSV: false,
+    }),
   },
 });
 
@@ -148,6 +148,8 @@ export const {
   testEmailSendEnd,
   setLastUid,
   addVisitedStep,
+  downloadCSVBegin,
+  downloadCSVEnd,
 } = reportsSlice.actions;
 
 export const reportsReducers = reportsSlice.reducer;
